kenchi package
==============

Subpackages
-----------

.. toctree::

    kenchi.outlier_detection
    kenchi.utils

Submodules
----------

.. toctree::

   kenchi.base
   kenchi.pipeline

Module contents
---------------

.. automodule:: kenchi
    :members:
    :undoc-members:
    :show-inheritance:
